@@ -11,9 +11,9 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
-// Copyright (c) 1996-2000 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
 // Basic Usage Environment: for a simple, non-scripted, console application
 // Implementation
 
@@ -28,13 +28,13 @@ public:
   AlarmHandler(TaskFunc* proc, void* clientData, DelayInterval timeToDelay)
     : DelayQueueEntry(timeToDelay), fProc(proc), fClientData(clientData) {
   }
-  
+
 private: // redefined virtual functions
   virtual void handleTimeout() {
     (*fProc)(fClientData);
     DelayQueueEntry::handleTimeout();
   }
-  
+
 private:
   TaskFunc* fProc;
   void* fClientData;
@@ -43,7 +43,8 @@ private:
 
 ////////// BasicTaskScheduler0 //////////
 
-BasicTaskScheduler0::BasicTaskScheduler0() {
+BasicTaskScheduler0::BasicTaskScheduler0()
+  : fLastHandledSocketNum(-1) {
   fReadHandlers = new HandlerSet;
 }
 
@@ -51,19 +52,20 @@ BasicTaskScheduler0::~BasicTaskScheduler0() {
   delete fReadHandlers;
 }
 
-TaskToken BasicTaskScheduler0::scheduleDelayedTask(int microseconds,
+TaskToken BasicTaskScheduler0::scheduleDelayedTask(int64_t microseconds,
 						 TaskFunc* proc,
 						 void* clientData) {
   if (microseconds < 0) microseconds = 0;
-  DelayInterval timeToDelay(microseconds/1000000, microseconds%1000000);
+  DelayInterval timeToDelay((long)(microseconds/1000000), (long)(microseconds%1000000));
   AlarmHandler* alarmHandler = new AlarmHandler(proc, clientData, timeToDelay);
   fDelayQueue.addEntry(alarmHandler);
 
-  return (void*)(alarmHandler->token()); 
+  return (void*)(alarmHandler->token());
 }
 
 void BasicTaskScheduler0::unscheduleDelayedTask(TaskToken& prevTask) {
   DelayQueueEntry* alarmHandler = fDelayQueue.removeEntry((long)prevTask);
+  prevTask = NULL;
   delete alarmHandler;
 }
 
@@ -80,11 +82,14 @@ void BasicTaskScheduler0::doEventLoop(char* watchVariable) {
 
 HandlerDescriptor::HandlerDescriptor(HandlerDescriptor* nextHandler) {
   // Link this descriptor into a doubly-linked list:
-  // (Note that this code works even if "nextHandler == this")
-  fNextHandler = nextHandler;
-  fPrevHandler = nextHandler->fPrevHandler;
-  nextHandler->fPrevHandler = this;
-  fPrevHandler->fNextHandler = this;
+  if (nextHandler == this) { // initialization
+    fNextHandler = fPrevHandler = this;
+  } else {
+    fNextHandler = nextHandler;
+    fPrevHandler = nextHandler->fPrevHandler;
+    nextHandler->fPrevHandler = this;
+    fPrevHandler->fNextHandler = this;
+  }
 }
 
 HandlerDescriptor::~HandlerDescriptor() {
@@ -119,7 +124,7 @@ void HandlerSet
     handler = new HandlerDescriptor(fHandlers.fNextHandler);
     handler->socketNum = socketNum;
   }
-  
+
   handler->handlerProc = handlerProc;
   handler->clientData = clientData;
 }
