@@ -11,9 +11,9 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
-// Copyright (c) 1996-2000, Live Networks, Inc.  All rights reserved
+// Copyright (c) 1996-2008, Live Networks, Inc.  All rights reserved
 //	Help by Carlo Bonamico to get working for Windows
 // Delay queue
 // Implementation
@@ -52,13 +52,13 @@ void Timeval::operator-=(const DelayInterval& arg2) {
 DelayInterval operator-(const Timeval& arg1, const Timeval& arg2) {
   time_base_seconds secs = arg1.seconds() - arg2.seconds();
   time_base_seconds usecs = arg1.useconds() - arg2.useconds();
-  
+
   if (usecs < 0) {
     usecs += MILLION;
     --secs;
   }
   if (secs < 0)
-    return ZERO;
+    return DELAY_ZERO;
   else
     return DelayInterval(secs, usecs);
 }
@@ -69,19 +69,19 @@ DelayInterval operator-(const Timeval& arg1, const Timeval& arg2) {
 DelayInterval operator*(short arg1, const DelayInterval& arg2) {
   time_base_seconds result_seconds = arg1*arg2.seconds();
   time_base_seconds result_useconds = arg1*arg2.useconds();
-  
+
   time_base_seconds carry = result_useconds/MILLION;
   result_useconds -= carry*MILLION;
   result_seconds += carry;
-  
+
   return DelayInterval(result_seconds, result_useconds);
 }
 
 #ifndef INT_MAX
 #define INT_MAX	0x7FFFFFFF
 #endif
-const DelayInterval ZERO(0, 0);
-const DelayInterval SECOND(1, 0);
+const DelayInterval DELAY_ZERO(0, 0);
+const DelayInterval DELAY_SECOND(1, 0);
 const DelayInterval ETERNITY(INT_MAX, MILLION-1);
 // used internally to make the implementation work
 
@@ -96,6 +96,9 @@ DelayQueueEntry::DelayQueueEntry(DelayInterval delay)
   fToken = ++tokenCounter;
 }
 
+DelayQueueEntry::~DelayQueueEntry() {
+}
+
 void DelayQueueEntry::handleTimeout() {
   delete this;
 }
@@ -120,9 +123,9 @@ void DelayQueue::addEntry(DelayQueueEntry* newEntry) {
     newEntry->fDeltaTimeRemaining -= cur->fDeltaTimeRemaining;
     cur = cur->fNext;
   }
-  
+
   cur->fDeltaTimeRemaining -= newEntry->fDeltaTimeRemaining;
-  
+
   // Add "newEntry" to the queue, just before "cur":
   newEntry->fNext = cur;
   newEntry->fPrev = cur->fPrev;
@@ -131,7 +134,7 @@ void DelayQueue::addEntry(DelayQueueEntry* newEntry) {
 
 void DelayQueue::updateEntry(DelayQueueEntry* entry, DelayInterval newDelay) {
   if (entry == NULL) return;
-  
+
   removeEntry(entry);
   entry->fDeltaTimeRemaining = newDelay;
   addEntry(entry);
@@ -144,7 +147,7 @@ void DelayQueue::updateEntry(long tokenToFind, DelayInterval newDelay) {
 
 void DelayQueue::removeEntry(DelayQueueEntry* entry) {
   if (entry == NULL || entry->fNext == NULL) return;
-  
+
   entry->fNext->fDeltaTimeRemaining += entry->fDeltaTimeRemaining;
   entry->fPrev->fNext = entry->fNext;
   entry->fNext->fPrev = entry->fPrev;
@@ -159,20 +162,20 @@ DelayQueueEntry* DelayQueue::removeEntry(long tokenToFind) {
 }
 
 DelayInterval const& DelayQueue::timeToNextAlarm() {
-  if (head()->fDeltaTimeRemaining == ZERO) return ZERO; // a common case
+  if (head()->fDeltaTimeRemaining == DELAY_ZERO) return DELAY_ZERO; // a common case
 
   synchronize();
   return head()->fDeltaTimeRemaining;
 }
 
 void DelayQueue::handleAlarm() {
-  if (head()->fDeltaTimeRemaining != ZERO) synchronize();
+  if (head()->fDeltaTimeRemaining != DELAY_ZERO) synchronize();
 
-  if (head()->fDeltaTimeRemaining == ZERO) {
+  if (head()->fDeltaTimeRemaining == DELAY_ZERO) {
     // This event is due to be handled:
     DelayQueueEntry* toRemove = head();
     removeEntry(toRemove); // do this first, in case handler accesses queue
-    
+
     toRemove->handleTimeout();
   }
 }
@@ -192,12 +195,12 @@ void DelayQueue::synchronize() {
   EventTime timeNow = TimeNow();
   DelayInterval timeSinceLastSync = timeNow - fLastSyncTime;
   fLastSyncTime = timeNow;
-  
+
   // Then, adjust the delay queue for any entries whose time is up:
   DelayQueueEntry* curEntry = head();
   while (timeSinceLastSync >= curEntry->fDeltaTimeRemaining) {
     timeSinceLastSync -= curEntry->fDeltaTimeRemaining;
-    curEntry->fDeltaTimeRemaining = ZERO;
+    curEntry->fDeltaTimeRemaining = DELAY_ZERO;
     curEntry = curEntry->fNext;
   }
   curEntry->fDeltaTimeRemaining -= timeSinceLastSync;
@@ -209,12 +212,7 @@ void DelayQueue::synchronize() {
 EventTime TimeNow() {
   struct timeval tvNow;
 
-#ifdef BSD
-  struct timezone Idunno;
-#else
-  int Idunno;
-#endif
-  gettimeofday(&tvNow, &Idunno);
+  gettimeofday(&tvNow, NULL);
 
   return EventTime(tvNow.tv_sec, tvNow.tv_usec);
 }
