@@ -11,10 +11,10 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2006 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
 // Descriptor preceding frames of 'ADU' MP3 streams (for improved loss-tolerance)
 // Implementation
 
@@ -59,7 +59,7 @@ unsigned ADUdescriptor::getRemainingFrameSize(unsigned char*& fromPtr) {
     return ((firstByte&0x3F)<<8) | secondByte;
   } else {
     // This is a 1-byte descriptor
-    return (firstByte&0x3F); 
+    return (firstByte&0x3F);
   }
 }
 
