@@ -11,10 +11,10 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2007 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
 // A filter for converting one or more MPEG Elementary Streams
 // to a MPEG-2 Transport Stream
 // Implementation
@@ -156,7 +156,7 @@ InputESSourceRecord
 		      FramedSource* inputSource,
 		      u_int8_t streamId, int mpegVersion,
 		      InputESSourceRecord* next)
-  : fNext(next), fParent(parent), fInputSource(inputSource), 
+  : fNext(next), fParent(parent), fInputSource(inputSource),
     fStreamId(streamId), fMPEGVersion(mpegVersion) {
   fInputBuffer = new unsigned char[INPUT_BUFFER_SIZE];
   reset();
