@@ -11,7 +11,7 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
 // Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
@@ -130,13 +130,24 @@ void RTPInterface::addStreamSocket(int sockNum,
   fTCPStreams = new tcpStreamRecord(sockNum, streamChannelId, fTCPStreams);
 }
 
+static void deregisterSocket(UsageEnvironment& env, int sockNum, unsigned char streamChannelId) {
+  SocketDescriptor* socketDescriptor = lookupSocketDescriptor(env, sockNum);
+  if (socketDescriptor != NULL) {
+    socketDescriptor->deregisterRTPInterface(streamChannelId);
+        // Note: This may delete "socketDescriptor",
+        // if no more interfaces are using this socket
+  }
+}
+
 void RTPInterface::removeStreamSocket(int sockNum,
 				      unsigned char streamChannelId) {
   for (tcpStreamRecord** streamsPtr = &fTCPStreams; *streamsPtr != NULL;
        streamsPtr = &((*streamsPtr)->fNext)) {
     if ((*streamsPtr)->fStreamSocketNum == sockNum
 	&& (*streamsPtr)->fStreamChannelId == streamChannelId) {
-      // Remove the record pointed to by *streamsPtr :
+      deregisterSocket(envir(), sockNum, streamChannelId);
+
+      // Then remove the record pointed to by *streamsPtr :
       tcpStreamRecord* next = (*streamsPtr)->fNext;
       (*streamsPtr)->fNext = NULL;
       delete (*streamsPtr);
@@ -195,7 +206,7 @@ Boolean RTPInterface::handleRead(unsigned char* buffer,
     // Read from the TCP connection:
     bytesRead = 0;
     unsigned totBytesToRead = fNextTCPReadSize;
-    if (totBytesToRead > bufferMaxSize) totBytesToRead = bufferMaxSize; 
+    if (totBytesToRead > bufferMaxSize) totBytesToRead = bufferMaxSize;
     unsigned curBytesToRead = totBytesToRead;
     int curBytesRead;
     while ((curBytesRead = readSocket(envir(), fNextTCPReadStreamSocketNum,
@@ -229,13 +240,7 @@ void RTPInterface::stopNetworkReading() {
   // Also turn off read handling on each of our TCP connections:
   for (tcpStreamRecord* streams = fTCPStreams; streams != NULL;
        streams = streams->fNext) {
-    SocketDescriptor* socketDescriptor
-      = lookupSocketDescriptor(envir(), streams->fStreamSocketNum);
-    if (socketDescriptor != NULL) {
-      socketDescriptor->deregisterRTPInterface(streams->fStreamChannelId);
-        // Note: This may delete "socketDescriptor",
-        // if no more interfaces are using this socket
-    }
+    deregisterSocket(envir(), streams->fStreamSocketNum, streams->fStreamChannelId);
   }
 }
 
@@ -382,4 +387,4 @@ tcpStreamRecord
 tcpStreamRecord::~tcpStreamRecord() {
   delete fNext;
 }
-                                                                                
+
