@@ -11,9 +11,9 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
-// Copyright (c) 1996-2000, Live Networks, Inc.  All rights reserved
+// Copyright (c) 1996-2008, Live Networks, Inc.  All rights reserved
 // A test program that receives a RTP/RTCP multicast MPEG video stream,
 // and outputs the resulting MPEG file stream to 'stdout'
 // main program
@@ -62,12 +62,12 @@ int main(int argc, char** argv) {
 #ifndef USE_SSM
   const unsigned char ttl = 1; // low, in case routers don't admin scope
 #endif
-  
+
   struct in_addr sessionAddress;
   sessionAddress.s_addr = our_inet_addr(sessionAddressStr);
   const Port rtpPort(rtpPortNum);
   const Port rtcpPort(rtcpPortNum);
-  
+
 #ifdef USE_SSM
   char* sourceAddressStr = "aaa.bbb.ccc.ddd";
                            // replace this with the real source address
@@ -82,19 +82,19 @@ int main(int argc, char** argv) {
   Groupsock rtpGroupsock(*env, sessionAddress, rtpPort, ttl);
   Groupsock rtcpGroupsock(*env, sessionAddress, rtcpPort, ttl);
 #endif
-  
+
   // Create the data source: a "MPEG Video RTP source"
   sessionState.source = MPEG1or2VideoRTPSource::createNew(*env, &rtpGroupsock);
 
   // Create (and start) a 'RTCP instance' for the RTP source:
-  const unsigned totalSessionBandwidth = 160; // in kbps; for RTCP b/w share
+  const unsigned estimatedSessionBandwidth = 160; // in kbps; for RTCP b/w share
   const unsigned maxCNAMElen = 100;
   unsigned char CNAME[maxCNAMElen+1];
   gethostname((char*)CNAME, maxCNAMElen);
   CNAME[maxCNAMElen] = '\0'; // just in case
   sessionState.rtcpInstance
     = RTCPInstance::createNew(*env, &rtcpGroupsock,
-			      totalSessionBandwidth, CNAME,
+			      estimatedSessionBandwidth, CNAME,
 			      NULL /* we're a client */, sessionState.source);
   // Note: This starts RTCP running automatically
 
