@@ -11,7 +11,7 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // Copyright (c) 1996-2008, Live Networks, Inc.  All rights reserved
 // A program that tests 'trick mode' operations on a MPEG-2 Transport Stream file,
@@ -114,7 +114,7 @@ int main(int argc, char const** argv) {
     *env << "Failed to open output file \"" << outputFileName << "\"\n";
     exit(1);
   }
-    
+
   // Start playing, to generate the output file:
   *env << "Writing output file \"" << outputFileName
        << "\" (start time " << startTime
